@@ -310,9 +310,9 @@ def upsert(
             # Function to compose col=excluded.col sql for update
             def set_str(cols: Iterable):
                 def exclude_sql(col):
-                    return sql.SQL("{}=excluded.{}").format(
+                    return sql.SQL("{}=EXCLUDED.{}").format(
+                        sql.Identifier(col),
                         sql.Identifier(col),
-                        sql.Placeholder(col),
                     )
 
                 return map(exclude_sql, cols)
@@ -328,6 +328,13 @@ def upsert(
                 else:
                     return sql.SQL(statement without where)
             """
+
+            # Silenced update_columns code as there is instances where
+            # you may need to update a key. timestamp when updating record
+            # leaving here for now in case i find issues later
+            # columns - keys, columns to update set etc
+            # update_columns = set(columns).difference(set(keys))
+
             try:
                 if uniform == 1:
                     qry = sql.SQL(
@@ -361,7 +368,7 @@ def upsert(
             # Catch no unique index error
             except errors.InvalidColumnReference as e:
                 print(">>> Error: ", e)
-                print("> Rolling back, attempt creation of new constriant...")
+                print(f"> Creating unique index for {keys}...")
                 conn.rollback()
 
                 # Add unique index & try again
@@ -500,7 +507,7 @@ def update(
                     sql.SQL(", ").join(column_value_str(columns)),
                     sql.SQL(", ").join(column_value_str(keys)),
                 )
-                print(qry.as_string(conn))
+                # print(qry.as_string(conn))
 
                 cur.executemany(query=qry, params_seq=rows)
             else:
@@ -584,7 +591,7 @@ def create_table(table: str, columns: dict, conn_kwargs: dict = None):
                 sql.Identifier(table),
                 sql.SQL(", ").join(define_column(columns)),
             )
-            print(qry.as_string(conn))
+            # print(qry.as_string(conn))
 
             cur.execute(query=qry)
 
